@@ -21,43 +21,30 @@ use std::fmt;
 use std::io;
 use std::string;
 
-use libhid;
-
-
 #[derive(Debug)]
 pub enum Error {
-  HidError(libhid::Error),
+  ArgparseError(i32),
   IoError(io::Error),
   Utf8Error(string::FromUtf8Error),
   Error(String),
 }
 
-
-impl From<libhid::Error> for Error {
-  fn from(e: libhid::Error) -> Error {
-    Error::HidError(e)
-  }
-}
-
-
 impl From<io::Error> for Error {
   fn from(e: io::Error) -> Error {
     Error::IoError(e)
   }
 }
 
-
 impl From<string::FromUtf8Error> for Error {
   fn from(e: string::FromUtf8Error) -> Error {
     Error::Utf8Error(e)
   }
 }
 
-
 impl fmt::Display for Error {
   fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
     match *self {
-      Error::HidError(ref e) => write!(f, "hidapi error: {}", e),
+      Error::ArgparseError(_) => write!(f, "Could not parse arguments"),
       Error::Utf8Error(_) => write!(f, "Encountered UTF-8 conversion error"),
       Error::IoError(ref e) => write!(f, "IO error: {}", e.get_ref().unwrap()),
       Error::Error(ref e) => write!(f, "{}", e),
